@@ -32,7 +32,7 @@ describe 'horizon' do
           :refreshonly => true,
       })}
       it {
-        if facts[:osfamily] == 'RedHat'
+        if facts[:os]['family'] == 'RedHat'
           is_expected.to contain_concat(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_cache]')
           is_expected.to contain_concat(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_compress]')
         else
@@ -50,7 +50,7 @@ describe 'horizon' do
 
       it 'configures apache' do
         is_expected.to contain_class('horizon::wsgi::apache').with({
-          :servername     => 'some.host.tld',
+          :servername     => 'foo.example.com',
           :listen_ssl     => false,
           :wsgi_processes => facts[:os_workers],
           :wsgi_threads   => '1',
@@ -65,9 +65,8 @@ describe 'horizon' do
           "LOGIN_URL = '#{platforms_params[:root_url]}/auth/login/'",
           "LOGOUT_URL = '#{platforms_params[:root_url]}/auth/logout/'",
           "LOGIN_REDIRECT_URL = '#{platforms_params[:root_url]}/'",
-          "ALLOWED_HOSTS = ['some.host.tld', ]",
+          "ALLOWED_HOSTS = ['foo.example.com', ]",
           'HORIZON_CONFIG["password_autocomplete"] = "off"',
-          'HORIZON_CONFIG["images_panel"] = "legacy"',
           "SECRET_KEY = 'elj1IWiLoWHgcyYxFVLj7cM5rGOOxWl0'",
           'OPENSTACK_KEYSTONE_URL = "http://127.0.0.1:5000"',
           'OPENSTACK_KEYSTONE_DEFAULT_ROLE = "member"',
@@ -99,50 +98,50 @@ describe 'horizon' do
     context 'with overridden parameters' do
       before do
         params.merge!({
-          :cache_backend                  => 'django.core.cache.backends.memcached.MemcachedCache',
-          :cache_options                  => {'SOCKET_TIMEOUT' => 1,'SERVER_RETRIES' => 1,'DEAD_RETRY' => 1},
-          :cache_server_ip                => '10.0.0.1',
-          :django_session_engine          => 'django.contrib.sessions.backends.cache',
-          :keystone_default_role          => 'SwiftOperator',
-          :keystone_url                   => 'https://keystone.example.com:4682',
-          :ssl_no_verify                  => true,
-          :log_handlers                   => ['console', 'syslog'],
-          :log_level                      => 'DEBUG',
-          :openstack_endpoint_type        => 'internalURL',
-          :secondary_endpoint_type        => 'ANY-VALUE',
-          :django_debug                   => true,
-          :site_branding                  => 'mysite',
-          :api_result_limit               => 2000,
-          :api_result_page_size           => 40,
-          :dropdown_max_items             => 123,
-          :compress_offline               => false,
-          :hypervisor_options             => {'can_set_mount_point' => false, 'can_set_password' => true },
-          :cinder_options                 => {'enable_backup' => true },
-          :keystone_options               => {'name' => 'native', 'can_edit_user' => true, 'can_edit_group' => true, 'can_edit_project' => true, 'can_edit_domain' => false, 'can_edit_role' => false},
-          :neutron_options                => {'enable_quotas' => false, 'enable_security_group' => false, 'enable_distributed_router' => false, 'enable_ha_router' => false,
-                                            'supported_provider_types' => ['flat', 'vxlan'], 'supported_vnic_types' => ['*'], 'default_ipv4_subnet_pool_label' => 'None', },
-          :instance_options               => {'disable_image' => true, 'disable_instance_snapshot' => true, 'disable_volume' => true, 'disable_volume_snapshot' => true, 'create_volume' => false },
-          :file_upload_temp_dir           => '/var/spool/horizon',
-          :wsgi_processes                 => '30',
-          :wsgi_threads                   => '5',
-          :secure_cookies                 => true,
-          :api_versions                   => {'identity' => 3},
-          :keystone_multidomain_support   => true,
-          :keystone_default_domain        => 'domain.tld',
-          :overview_days_range            => 1,
-          :session_timeout                => 1800,
-          :timezone                       => 'Asia/Shanghai',
-          :available_themes               => [
+          :cache_backend                    => 'django.core.cache.backends.memcached.MemcachedCache',
+          :cache_options                    => {'SOCKET_TIMEOUT' => 1,'SERVER_RETRIES' => 1,'DEAD_RETRY' => 1},
+          :cache_server_ip                  => '10.0.0.1',
+          :django_session_engine            => 'django.contrib.sessions.backends.cache',
+          :keystone_default_role            => 'SwiftOperator',
+          :keystone_url                     => 'https://keystone.example.com:4682',
+          :ssl_no_verify                    => true,
+          :log_handlers                     => ['console', 'syslog'],
+          :log_level                        => 'DEBUG',
+          :openstack_endpoint_type          => 'internalURL',
+          :secondary_endpoint_type          => 'ANY-VALUE',
+          :openstack_keystone_endpoint_type => 'public',
+          :django_debug                     => true,
+          :site_branding                    => 'mysite',
+          :api_result_limit                 => 2000,
+          :api_result_page_size             => 40,
+          :dropdown_max_items               => 123,
+          :compress_offline                 => false,
+          :hypervisor_options               => {'can_set_mount_point' => false, 'can_set_password' => true },
+          :cinder_options                   => {'enable_backup' => true },
+          :keystone_options                 => {'name' => 'native', 'can_edit_user' => true, 'can_edit_group' => true, 'can_edit_project' => true, 'can_edit_domain' => false, 'can_edit_role' => false},
+          :neutron_options                  => {'enable_quotas' => false, 'enable_security_group' => false, 'enable_distributed_router' => false, 'enable_ha_router' => false,
+                                                'supported_provider_types' => ['flat', 'vxlan'], 'supported_vnic_types' => ['*'], 'default_ipv4_subnet_pool_label' => 'None', },
+          :instance_options                 => {'disable_image' => true, 'disable_instance_snapshot' => true, 'disable_volume' => true, 'disable_volume_snapshot' => true, 'create_volume' => false },
+          :file_upload_temp_dir             => '/var/spool/horizon',
+          :wsgi_processes                   => '30',
+          :wsgi_threads                     => '5',
+          :secure_cookies                   => true,
+          :api_versions                     => {'identity' => 3},
+          :keystone_multidomain_support     => true,
+          :keystone_default_domain          => 'domain.tld',
+          :overview_days_range              => 1,
+          :session_timeout                  => 1800,
+          :timezone                         => 'Asia/Shanghai',
+          :available_themes                 => [
             { 'name' => 'default', 'label' => 'Default', 'path' => 'themes/default' },
             { 'name' => 'material', 'label' => 'Material', 'path' => 'themes/material' },
           ],
-          :default_theme                  => 'default',
-          :password_autocomplete          => 'on',
-          :images_panel                   => 'angular',
-          :create_image_defaults          => {'image_visibility' => 'private'},
-          :password_retrieve              => true,
-          :enable_secure_proxy_ssl_header => true,
-          :secure_proxy_addr_header       => 'HTTP_X_FORWARDED_FOR',
+          :default_theme                    => 'default',
+          :password_autocomplete            => 'on',
+          :create_image_defaults            => {'image_visibility' => 'private'},
+          :password_retrieve                => true,
+          :enable_secure_proxy_ssl_header   => true,
+          :secure_proxy_addr_header         => 'HTTP_X_FORWARDED_FOR',
         })
       end
 
@@ -150,7 +149,7 @@ describe 'horizon' do
         verify_concat_fragment_contents(catalogue, 'local_settings.py', [
           'DEBUG = True',
           "SITE_BRANDING = 'mysite'",
-          "ALLOWED_HOSTS = ['some.host.tld', ]",
+          "ALLOWED_HOSTS = ['foo.example.com', ]",
           "SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTO', 'https')",
           "SECURE_PROXY_ADDR_HEADER = 'HTTP_X_FORWARDED_FOR'",
           'CSRF_COOKIE_SECURE = True',
@@ -160,7 +159,6 @@ describe 'horizon' do
           "OPENSTACK_KEYSTONE_MULTIDOMAIN_SUPPORT = True",
           "OPENSTACK_KEYSTONE_DEFAULT_DOMAIN = 'domain.tld'",
           'HORIZON_CONFIG["password_autocomplete"] = "on"',
-          'HORIZON_CONFIG["images_panel"] = "angular"',
           "SECRET_KEY = 'elj1IWiLoWHgcyYxFVLj7cM5rGOOxWl0'",
           "        'OPTIONS': {",
           "            'DEAD_RETRY': 1,",
@@ -200,6 +198,7 @@ describe 'horizon' do
           "    'enable_scheduler_hints': True,",
           'OPENSTACK_ENDPOINT_TYPE = "internalURL"',
           'SECONDARY_ENDPOINT_TYPE = "ANY-VALUE"',
+          'OPENSTACK_KEYSTONE_ENDPOINT_TYPE = "public"',
           'API_RESULT_LIMIT = 2000',
           'API_RESULT_PAGE_SIZE = 40',
           'DROPDOWN_MAX_ITEMS = 123',
@@ -401,7 +400,7 @@ describe 'horizon' do
       before do
         params.merge!({
           :listen_ssl        => true,
-          :servername        => 'some.host.tld',
+          :servername        => 'foo.example.com',
           :ssl_cert          => '/etc/pki/tls/certs/httpd.crt',
           :ssl_key           => '/etc/pki/tls/private/httpd.key',
           :ssl_ca            => '/etc/pki/tls/certs/ca.crt',
@@ -526,19 +525,7 @@ describe 'horizon' do
         verify_concat_fragment_contents(catalogue, 'local_settings.py', [
           '# Custom local_settings.py',
           'DEBUG = True',
-          "HORIZON_CONFIG = {",
-          "    'user_home': 'openstack_dashboard.views.get_user_home',",
-          "    'ajax_queue_limit': 10,",
-          "    'auto_fade_alerts': {",
-          "        'delay': 3000,",
-          "        'fade_duration': 1500,",
-          "        'types': ['alert-success', 'alert-info']",
-          "    },",
-          "    'help_url': \"https://docs.openstack.org\",",
-          "    'exceptions': {'recoverable': exceptions.RECOVERABLE,",
-          "                   'not_found': exceptions.NOT_FOUND,",
-          "                   'unauthorized': exceptions.UNAUTHORIZED},",
-          "}",
+          'HORIZON_CONFIG["help_url"] = "https://docs.openstack.org"',
         ])
       end
     end
@@ -696,61 +683,20 @@ describe 'horizon' do
       end
     end
 
-    context 'with customization_module provided' do
+    context 'with help_url, bug_url and customization_module provided' do
       before do
         params.merge!({
-          :help_url                => 'https://docs.openstack.org',
-          :customization_module    => 'my_project.overrides',
-          :local_settings_template => fixtures_path + '/override_local_settings.py.erb'
+          :help_url             => 'https://docs.openstack.org',
+          :bug_url              => 'https://bugs.launchpad.net',
+          :customization_module => 'my_project.overrides',
         })
       end
 
-      it 'uses the custom local_settings.py template' do
+      it 'configures all options' do
         verify_concat_fragment_contents(catalogue, 'local_settings.py', [
-          '# Custom local_settings.py',
-          "HORIZON_CONFIG = {",
-          "    'user_home': 'openstack_dashboard.views.get_user_home',",
-          "    'ajax_queue_limit': 10,",
-          "    'auto_fade_alerts': {",
-          "        'delay': 3000,",
-          "        'fade_duration': 1500,",
-          "        'types': ['alert-success', 'alert-info']",
-          "    },",
-          "    'help_url': \"https://docs.openstack.org\",",
-          "    'exceptions': {'recoverable': exceptions.RECOVERABLE,",
-          "                   'not_found': exceptions.NOT_FOUND,",
-          "                   'unauthorized': exceptions.UNAUTHORIZED},",
-          "    'customization_module': 'my_project.overrides',",
-          "}",
-        ])
-      end
-    end
-
-    context 'with customization_module empty' do
-      before do
-        params.merge!({
-          :help_url                => 'https://docs.openstack.org',
-          :customization_module    => '',
-          :local_settings_template => fixtures_path + '/override_local_settings.py.erb'
-        })
-      end
-
-      it 'uses the custom local_settings.py template' do
-        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
-          '# Custom local_settings.py',
-          "HORIZON_CONFIG = {",
-          "    'user_home': 'openstack_dashboard.views.get_user_home',",
-          "    'ajax_queue_limit': 10,",
-          "    'auto_fade_alerts': {",
-          "        'delay': 3000,",
-          "        'fade_duration': 1500,",
-          "        'types': ['alert-success', 'alert-info']",
-          "    },",
-          "    'help_url': \"https://docs.openstack.org\",",
-          "    'exceptions': {'recoverable': exceptions.RECOVERABLE,",
-          "                   'not_found': exceptions.NOT_FOUND,",
-          "                   'unauthorized': exceptions.UNAUTHORIZED},",
-          "}",
+          'HORIZON_CONFIG["help_url"] = "https://docs.openstack.org"',
+          'HORIZON_CONFIG["bug_url"] = "https://bugs.launchpad.net"',
+          'HORIZON_CONFIG["customization_module"] = "my_project.overrides"',
         ])
       end
     end
@@ -810,17 +756,13 @@ describe 'horizon' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge!(OSDefaults.get_facts({
-          :fqdn           => 'some.host.tld',
-          :concat_basedir => '/var/lib/puppet/concat',
-          :os_workers     => '6'
-        }))
+        facts.merge!(OSDefaults.get_facts())
       end
 
       let(:platforms_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
-          if facts[:operatingsystem] == 'Debian'
+          if facts[:os]['name'] == 'Debian'
             { :config_file        => '/etc/openstack-dashboard/local_settings.py',
               :conf_d_dir         => '/etc/openstack-dashboard/local_settings.d',
               :package_name       => 'openstack-dashboard-apache',
@@ -858,7 +800,7 @@ describe 'horizon' do
       end
 
       it_behaves_like 'horizon'
-      it_behaves_like "horizon on #{facts[:osfamily]}"
+      it_behaves_like "horizon on #{facts[:os]['family']}"
     end
   end
 end
